@@ -2,8 +2,9 @@ use std::env::current_dir;
 use std::fs::create_dir_all;
 
 use cosmwasm_schema::{export_schema, remove_schemas, schema_for};
+use cw20_base::msg::{InstantiateMsg, QueryMsg};
+use cw20_factory_token::msg::ExecuteMsg;
 
-use cw20_factory_token::msg::{ExecuteMsg, QueryMsg, InstantiateMsg};
 
 fn main() {
     let mut out_dir = current_dir().unwrap();
